pg.ddx.io  pgsql-hackers@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Tom Lane <tgl@sss.pgh.pa.us>
To: Dimitrios Apostolou <jimis@gmx.net>
Cc: Chao Li <li.evan.chao@gmail.com>
Cc: Nathan Bossart <nathandbossart@gmail.com>
Cc: Thomas Munro <thomas.munro@gmail.com>
Cc: pgsql-hackers@lists.postgresql.org
Subject: Re: [PATCH v4] parallel pg_restore: avoid disk seeks when jumping short distance forward
Date: Mon, 20 Oct 2025 18:15:13 -0400
Message-ID: <381756.1760998513@sss.pgh.pa.us> (raw)
In-Reply-To: <375562.1760995276@sss.pgh.pa.us>
References: <2edb7a57-b225-3b23-a680-62ba90658fec@gmx.net>
	<a7344d8f-927c-1f97-6cc0-ac630deb98c4@gmx.net>
	<c0e531f9-accc-3a93-e9e6-2cec1471f9e9@gmx.net>
	<1282067.1744651649@sss.pgh.pa.us>
	<c6bb93c1-4042-743c-096c-27c5e7c73347@gmx.net>
	<f7a23708-c336-c189-f155-4b3197bf6ea0@gmx.net>
	<aEioDuePEBRnfJYk@nathan>
	<5ed51587-5a24-4d79-e36e-927620d0e3a2@gmx.net>
	<aEygf8AchBk04gOA@nathan>
	<f99e9774-da49-60f0-20e0-b97d9f12a04e@gmx.net>
	<72d2c81b-a0fe-3d99-9dd4-0d771e6e673e@gmx.net>
	<1po8os49-r63o-2923-p37n-12698o1qn7p0@tzk.arg>
	<3515357.1760128017@sss.pgh.pa.us>
	<3698234.1760149336@sss.pgh.pa.us>
	<3686.1760232320@sss.pgh.pa.us>
	<CBF70398-279C-4BA7-9FA1-2879A49F4EC9@gmail.com>
	<717335.1760389672@sss.pgh.pa.us>
	<1306492.1760556110@sss.pgh.pa.us>
	<1518975.1760634070@sss.pgh.pa.us>
	<9opr64ps-625r-667n-q19o-op35rs414n59@tzk.arg>
	<375562.1760995276@sss.pgh.pa.us>

I wrote:
> So for me, the proposed patch actually makes it 2X slower.

I went and tried this same test case on a 2024 Mac Mini M4 Pro.
Cutting to the chase:

HEAD:

$ time pg_restore -f /dev/null -t zedtable bench10000.dump

real    1m26.525s
user    0m0.364s
sys     0m6.806s

Patched:

$ time pg_restore -f /dev/null -t zedtable bench10000.dump

real    0m15.419s
user    0m0.279s
sys     0m8.224s

So on this hardware it *does* win (although maybe things would
be different for a parallel restore).  The patched pg_restore
takes just about the same amount of time as "cat", and iostat
shows both of them reaching a bit more than 6GB/s read speed.

My feeling at this point is that we'd probably drop the block
size test as irrelevant, and instead simply ignore ctx->hasSeek
within this loop if we think we're on a platform where that's
the right thing.  But how do we figure that out?

Not sure where we go from here, but clearly a bunch of research
is going to be needed to decide whether this is committable.

			regards, tom lane





view thread (47+ messages)  latest in thread

Message-ID: <381756.1760998513@sss.pgh.pa.us>
Permalink:  ../381756.1760998513@sss.pgh.pa.us/
Also on:    postgresql.org/message-id/381756.1760998513@sss.pgh.pa.us

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-hackers@postgresql.org
  Cc: tgl@sss.pgh.pa.us, jimis@gmx.net, li.evan.chao@gmail.com, nathandbossart@gmail.com, thomas.munro@gmail.com, pgsql-hackers@lists.postgresql.org
  Subject: Re: [PATCH v4] parallel pg_restore: avoid disk seeks when jumping short distance forward
  In-Reply-To: <381756.1760998513@sss.pgh.pa.us>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox